Crate crate_crypto_internal_eth_kzg_erasure_codes

Crate crate_crypto_internal_eth_kzg_erasure_codes 

Modules

errors

Structs

BlockErasureIndices
A list of erased indices that appear at the same relative position in every block of the codeword.
ReedSolomon
A Reed-Solomon encoder and erasure decoder over a multiplicative subgroup domain.